@@ -1279,85 +1279,3 @@ setMethodS3(
   overwrite=TRUE,
   conflict="warning"
 );
-
-###########################################################################/**
-# @RdocMethod clone
-#
-# @title "Clones an Object"
-#
-# \description{
-#  Creates an identical copy of the object and returns a reference to the
-#  new object.
-#
-#  This is a modified version of the \code{\link{clone.Object}} method from the
-#  \code{\link{R.oo}} package.
-# }
-#
-# @synopsis
-#
-# \arguments{
-#   \item{this}{An object inheriting from PSRoot.}
-#   \item{...}{Not used.}
-# }
-#
-# \value{
-#   A reference to the new object.
-# }
-#
-# \examples{
-#   o1 <- PSRoot()
-#   o2 <- clone(o1)
-#
-#   print(equals(o1, o2))
-# }
-#
-# \details{
-#   Please note that no constructors are called during the creation of the
-#   clone and neither is any static class code called.
-# }
-#
-# \seealso{
-#   @seeclass
-# }
-#
-# @author
-#
-#*/###########################################################################
-setMethodS3("clone", "PSRoot", function(this, ...) {
-
-	## WARNING: This method might fail if the internal workings
-	## of the R.oo package changes!
-
-	# Copy the reference.
-	clone <- this
-
-  	# Create a new environment, i.e. a new Object.
-	clone.env <- .Internal(new.env(FALSE,.Internal(parent.frame(1)),size=29L));
-	attr(x=clone, which=".env") <- clone.env;
-
-	# Copy all variables in the environment.
-	this.env <- attr(this, ".env");
-
-  	for (field in .Internal(ls(attr(this, ".env"), TRUE)) ) {
-
-		value <- .Internal(get(field, this.env, "any", FALSE));
-		# The following line must be included to do nothing, but the effect
-		# is that it fools the lazy evaluation (?) to create a true copy of
-		# the object. If this is not done, it won't be a true clone even if
-		# the value is assigned to another environment. Example:
-		#  b <- clone(a) 
-		#  b$matrix[1,1] <- 2
-		# will otherwise also change a$matrix[1,1]. /HB 021023
-		attr(value, "R.oo::.clone.Object") <- NULL;
-		assign(field, value, envir=clone.env);
-		.Internal(assign(field, value, clone.env, FALSE));
-
- 	}
-	clone;
-	
-},
-  private=FALSE,
-  protected=FALSE,
-  overwrite=TRUE,
-  conflict="warning"
-);
